@@ -2,7 +2,7 @@ package Test2::Util;
 use strict;
 use warnings;
 
-our $VERSION = '1.302021';
+our $VERSION = '1.302023';
 
 
 use Config qw/%Config/;
@@ -32,7 +32,7 @@ sub _can_thread {
     # Threads are broken on perl 5.10.0 built with gcc 4.8+
     if ($] == 5.010000 && $Config{'ccname'} eq 'gcc' && $Config{'gccversion'}) {
         my @parts = split /\./, $Config{'gccversion'};
-        return 0 if $parts[0] >= 4 && $parts[1] >= 8;
+        return 0 if $parts[0] > 4 || ($parts[0] == 4 && $parts[1] >= 8);
     }
 
     # Change to a version check if this ever changes
